/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2022 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system                           *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.18.0.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for TI MSP430x5438 eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include <msp430x54x.h>

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT      (0)  /* LED1 active low */
#define LED1_BIT      (1)  /* LED2 active low */
#define LEDPORT_DIR   P1DIR
#define LEDPORT_OUT   P1OUT

#define LEDMASK_ALL   ((1uL << LED0_BIT) | (1uL << LED1_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  LEDPORT_DIR   =  LEDMASK_ALL;  /* Switch to output mode */
  LEDPORT_OUT  &= ~LEDMASK_ALL;  /* Initially clear LEDs  */
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  LEDPORT_OUT |= (1uL << Index);         /* Switch on LED  */
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  LEDPORT_OUT &= ~(1uL << Index);        /* Switch off LED */
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (LEDPORT_OUT & (1uL << Index)) {    /* LED is switched on */
    BSP_ClrLED(Index);
  } else {
    BSP_SetLED(Index);
  }
}

/****** End Of File *************************************************/
